#!/bin/sh
# $Id: preinstall.sh,v 1.36 2008/04/12 13:28:28 lav Exp $
# Install some preneeded packages.
# See in redist.html for additional information.

# Note: remove placeholders before native dlls installing!

SYSDIR="$CROOT/windows/system32"
SYSDIRW="C:\\windows\\system32"
PROGDIR="$CROOT/Program Files/"
DOWNLOADS="$CROOT/windows/downloads"

# Remove listed dlls
predel()
{
	for i in $@ ; do
		rm -f "$SYSDIR/$i"
	done
}

failed()
{
	echo "      [ ERROR ]"
	[ "$FORCE" = "y" ] || exit 1
}

try_reg()
{
	if [ -e "$SYSDIR/$1" ] ; then
		$WINELOADER regsvr32.exe "$SYSDIR\\$1" 2>>$WINEPREFIX/install.log
	fi
}


install_dll()
{
TOINSTALL=$DOWNLOADS/vcredist.exe
if [ -e $TOINSTALL ] ; then
	echo "VC6 redistributable components installing..."
	predel msvcrt.dll oleaut32.dll olepro32.dll asycfilt.dll comcat.dll msvcp60.dll MSVCRT.DLL MFC42.DLL mfc42.dll mfc42u.dll
	# vcredist still exits with status 43.  Anyone know why?
	WINDOWS_VERSION=winxp $WINELOADER $TOINSTALL /Q:A || true
	test -f $SYSDIR/msvcrt.dll || failed
	test -f $SYSDIR/mfc42.dll || failed
	# TODO: unpack mfc32u from vcredist (/Q /C /T:path - extract all files), now distribute it in wine-school-components
	# See http://support.microsoft.com/kb/259403/ru
	# vcredist removed mfc42u.dll if it preexists
	cp -f ${WINEDATADIR}/skel/windows/system32/mfc42u.dll $SYSDIR/mfc42u.dll
	test -f $SYSDIR/mfc42u.dll || failed
	predel oleaut32.dll olepro32.dll
fi

step_progress
TOINSTALL=$DOWNLOADS/vcredist_x86.exe
if [ -e $TOINSTALL ] ; then
	echo "VC2003 redistributable components installing..."
	predel mfc80.dll
	WINDOWS_VERSION=win98 $WINELOADER $TOINSTALL /Q:A
	test -f $SYSDIR/mfc80.dll || failed
fi

step_progress
TOINSTALL=$DOWNLOADS/WindowsXP-Windows2000-Script56-KB917344-x86-enu.exe
if [ -e $TOINSTALL ] ; then
	echo "Windows Scripting installing..."
	predel wscript.exe WSCRIPT.EXE
	WINDOWS_VERSION=win98 $WINELOADER $TOINSTALL /Q:A
	test -f $SYSDIR/wscript.exe || failed
fi

step_progress
TOINSTALL=$DOWNLOADS/klcodec390s.exe
if [ -e $TOINSTALL ] ; then
	echo "K-Lite Codec installing..."
	WINDOWS_VERSION=winxp $WINELOADER $TOINSTALL /VERYSILENT
	test -f "$PROGDIR/K-Lite Codec Pack/Filters/vsfilter.dll" || failed
	echo "Registering multimedia formats..."
	$WINELOADER "$PROGDIR/K-Lite Codec Pack/Media Player Classic/mplayerc.exe" /regaud /regvid
fi

step_progress
step_progress
TOINSTALL=$DOWNLOADS/ppviewer.exe
if [ -e $TOINSTALL ] ; then
	echo "Power Point Viewer 2003 installing..."
	predel GDIPLUS.DLL gdiplus.dll
	WINDOWS_VERSION=winxp $WINELOADER $TOINSTALL /Q:A
	cp -f "$PROGDIR/Microsoft Office/PowerPoint Viewer/GDIPLUS.DLL" $SYSDIR/
	test -f $SYSDIR/GDIPLUS.DLL || failed
fi

step_progress
TOINSTALL=$DOWNLOADS/MDAC_TYP.EXE
if [ -e $TOINSTALL ] ; then
	echo "MDAC 2.8 installing..."
	predel odbc32.dll ODBC32.DLL
	# Set Windows 98 version for override msxml3 to new version
	WINDOWS_VERSION=win98 $WINELOADER $TOINSTALL /Q:A /C:"dasetup /Q" 2>/dev/null
	test -f $SYSDIR/odbc32.dll || failed
fi

step_progress
TOINSTALL=$DOWNLOADS/jet40sp8_wme.exe
if [ -e $TOINSTALL ] ; then
	echo "MSJET 4.0 installing..."
	predel ../inf/catalog/jet8USA.cat
	WINDOWS_VERSION=winxp $WINELOADER $TOINSTALL /Q:A /C:"jetsetup /Q:A" 2>/dev/null
	test -f $SYSDIR/../inf/catalog/jet8USA.cat || failed
fi

step_progress
UNZIP="$WINELOADER unzip -o"
NPMOZAX=$DOWNLOADS/npmozax-fx2.0.11.xpi
NPMOZAXW="C:\\windows\\downloads\\npmozax-fx2.0.11.xpi"
if [ -e $NPMOZAX ] ; then
	echo "Mozilla Active X plugin installing..."
	cd $SYSDIR/../gecko/0.1.0/wine_gecko/ || failed
	$UNZIP $NPMOZAXW npmozax.dll -d plugins || failed
	$UNZIP $NPMOZAXW activex.js install.js -d greprefs || failed
	$UNZIP $NPMOZAXW nsAxSecurityPolicy.js nsIMozAxPlugin.xpt -d components || failed
	cd - >/dev/null
	cd $SYSDIR
	$UNZIP $NPMOZAXW msvcp71.dll || failed
# msvcp71.dll , msvcr71.dll , MFC71.dll
	cd - >/dev/null
fi

step_progress
cd $DOWNLOADS
TOINSTALL=install_flash_player_active_x.msi
if [ -e $TOINSTALL ] ; then
	echo "Flash Player 9 ActiveX installing..."
	WINDOWS_VERSION=winxp $WINELOADER msiexec /i $TOINSTALL /q
fi
cd - >/dev/null

# Hack for use our mplayer wrapper
if cp -f ${WINECONFDIR}/mplayer.reg "$CROOT/windows/inf/mplayer.reg" ; then
	"${WINELOADER}" regedit.exe "$CROOT/windows/inf/mplayer.reg"
fi

}

# Run install DLLs only if has admin permissions (write to C: drive)
if [ -w "$CROOT" ] && [ "$WINEMODE" != "--attach" ] ; then
	install_dll 2>>$WINEPREFIX/install.log
else
	echo "Skip dlls installing (just attaching...)"
fi

# Register DLLs
try_reg msxml3.dll
try_reg msxml4.dll
try_reg vbscript.dll
try_reg jscript.dll
try_reg wmp.dll
